from setuptools import setup

setup(
    name='rfrsilva-package',
    version='0.1',
    packages=['rfrsilva-package'],
    url='https://github.com/rfrsilva/rfrsilva-package',
    license='Apache 2.0',
    author='kubernetesworker',
    author_email='rui.fsilva@hotmail.com',
    description='Left-pad implementation'
)
